import unittest

from config import (
    tape,
    user_id,
    opponent_id,
    YaylibTestCase,
)


class YaylibMiscTests(YaylibTestCase):
    path = "./misc/"


if __name__ == "__main__":
    unittest.main()
